@@ -1,16 +1,19 @@
 use 5.014;
-#package Thread::Queue::Any '1.12'; # not supported by PAUSE or MetaCPAN :-(
+#package Thread::Queue::Any '1.14'; # not supported by PAUSE or MetaCPAN :-(
 package Thread::Queue::Any;         # please remove if no longer needed
 
 # initializations
 our @ISA= qw( Thread::Queue );
-our $VERSION= '1.12';               # please remove if no longer needed
+our $VERSION= '1.14';               # please remove if no longer needed
 
 # be as verbose as possble
 use warnings;
 
 # modules that we need
 use Thread::Queue (); # no need to pollute namespace
+BEGIN {
+    *ISHASH = sub () { $Thread::Queue::VERSION >= 3 }
+}
 
 # synonym for dequeue_dontwait
 {
@@ -76,9 +79,9 @@ sub dequeue_dontwait {
 sub dequeue_keep {
 
     # make sure we're the only one
-    lock( @{ $_[0] } );
+    lock( ISHASH ? $_[0] : @{ $_[0] } );
 
-    my $ref= shift->[0] or return;
+    my $ref= ( ISHASH ? shift->{queue}->[0] : shift->[0] ) or return;
     return wantarray
       ? @{ $THAW->($ref) }
       : $THAW->($ref)->[0];
@@ -135,7 +138,8 @@ sub import {
     if ( my @huh= keys %param ) {
         push @errors, "Don't know what to do with: @huh";
     }
-    die join "\n", "Found the following errors:", @errors if @errors;
+    die join "\n", "Found the following errors:", @errors
+      if @errors;
 
     # found specific serializer
     if ($serializer) {
@@ -177,7 +181,8 @@ sub _set_serializer {
       or push @errors, "$class does not provide a 'thaw' method";
 
     # huh?
-    die join "\n", "Found the following errors:", @errors if @errors;
+    die join "\n", "Found the following errors:", @errors
+      if @errors;
 
     # it's all ok
     $SERIALIZER= $class;
@@ -218,7 +223,7 @@ Thread::Queue::Any - thread-safe queues for any data-structure
 
 =head1 VERSION
 
-This documentation describes version 1.12.
+This documentation describes version 1.14.
 
 =head1 DESCRIPTION
 
@@ -379,6 +384,9 @@ systems like so:
 If your perl does not support the "blead" version of the code, then it will
 automatically install the "maint" version of the code.
 
+Please note that any additional parameters will simply be passed on to the
+underlying Makefile.PL processing.
+
 =head1 AUTHOR
 
 Elizabeth Mattijsen, <liz@dijkmat.nl>.
